*************************************************************************
*                                                                       *  
* How Mediator Leadership Transitions Influence Mediation Effectiveness *
*                                                                       *
* Marius Mehrl and Tobias Böhmelt                                       *   
*                                                                       *
* This Version: March 11, 2020                                          *
*                                                                       *
*************************************************************************

use "C:\Box\myBox\Mediation SOLS Change\CMPS Replication\CMPS Leadership Changes Mediation.dta", clear // change data set directory if necessary

keep duration med_onset year stsetid ep_end med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a side_b ///
conflict_outcome conflict_id incompatibility lchange_med_yearly cwm_success medendyear medstartyear bdeadbes mediator1 mediator2 mediator3 mediator4 mediator5 mediator6 /// 
mediator7 mediator8 mediator9 mediator10 mediator11 leadertrans_sidea avmed_polity2 avmed_wincolsize med_yearly

stset duration, id(stsetid) failure(ep_end==1)

btscs med_onset  year stsetid , g(medyrs) nspline(3)
gen exitsamp=(ep_end-1)*(-1)

*****************
* Main Analyses *
*****************

* Table 1 *

stcox med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox med_onset lchange_med, nohr cluster(conflict_id)
stcox med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Figure 1 - Left Panel *

stcox med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcurve, surv at1(lchange_med=1 med_onset=1) at2(lchange_med=0 med_onset=1) title("Model 3") xtitle("Years of Conflict") ytitle("Survivor Function") lpattern(dash shortdash solid) lcolor(gs6 gs8 gs0) legend(label(3 "No Mediation") label(2 "Mediaton: No Leadership Change") label(1 "Mediaton: Leadership Change") position(6)) name(graph5, replace) scheme(plotplain) aspectratio(1)

* Figure 1 - Right Panel *

dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) time cluster(conflict_id) rtcensor(exitsamp)
preserve
keep duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3 conflict_id exitsamp stsetid conflict_id year med_onset
collapse (mean) _all (min) wsurvmin=duration (max) wsurvmax=duration if med_onset==1    
expand 3
replace duration = wsurvmin if _n==2
replace duration = wsurvmax if _n==3
replace lchange_med = 1 if _n==2
replace lchange_med = 0 if _n==3
durselgr duration if _n==1, survival saving(mean, replace) nograph
durselgr duration if _n==2, survival saving(lchange_med1, replace) nograph
durselgr duration if _n==3, survival saving(lchange_med0, replace) nograph
restore
use "C:\Box\myBox\Mediation SOLS Change\CMPS Replication\mean.dta", clear
rename survival surv_mean
joinby _t using lchange_med1
rename survival lchange_med1
joinby _t using lchange_med0
rename survival lchange_med0
twoway line lchange_med1 lchange_med0 _t, scheme(plotplain) clpattern(solid longdash shortdash dash_dot) xtitle("Years of Conflict") ytitle("Survival Function: Model 4") yline(0) ylabel(0.0(0.25)1) title("") legend(label(1 "Mean Survival Function") label(2 "Survival Function: Leadership Change") label(3 "Survival Function: No Leadership Change")) legend(off) aspectratio(1)

*********************
* Appendix Analyses *
*********************

use "C:\Box\myBox\Mediation SOLS Change\CMPS Replication\CMPS Leadership Changes Mediation.dta", clear // change data set directory if necessary
stset duration, id(stsetid) failure(ep_end==1)
btscs med_onset  year stsetid , g(medyrs) nspline(3)
gen exitsamp=(ep_end-1)*(-1)

* Table A2 *

gen militaryfaction =  strpos(side_b, "Military") > 0
* From CSG 2009: Popular Revolutionary Movement; MNR; Nationalists (Iraq 1959); Sudanese Communist Party (1971); Islamic Charter Front (Sudan 1976); JVP (Sri Lanka 1971)
* SRLP (Gambia 1981); MTD (Togo 1986);  Popular Front   (Burkina Faso 1987);  Presidential guard (Comoros 1989);  Jamaat al-Muslimeen  (Trinidad 1990)
gen coup=0
replace coup=1 if militaryfaction==1
replace coup=1 if side_b=="Popular Revolutionary Movement"
replace coup=1 if side_b=="MNR"
replace coup=1 if side_b=="Nationalists"
replace coup=1 if side_b=="Sudanese Communist Party"
replace coup=1 if side_b=="Islamic Charter Front"
replace coup=1 if side_b=="JVP" & year==1971
replace coup=1 if side_b=="SRLP"
replace coup=1 if side_b=="MTD"
replace coup=1 if side_b=="Popular Front" & year==1987
replace coup=1 if side_b=="Presidential"
replace coup=1 if side_b=="Jamaat al-Muslimeen"
gen evntl_outcome=conflict_outcome
bysort conflict_id: replace evntl_outcome=evntl_outcome[_n+1] if evntl_outcome==.
replace evntl_outcome=0 if evntl_outcome==.

stcox lchange_med cumulative_intensity lnpop rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id) tvc(med_onset lngdppc)
stcox med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id) strata(incompatibility coup)
stcox med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id) strata(evntl_outcome)

* Table A3 *

dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(weibull) time cluster(conflict_id) rtcensor(exitsamp)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(lognormal) cluster(conflict_id) rtcensor(exitsamp)

* Table A4 *

stcox lchange_med med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a if duration<7, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a if duration<7, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A5 *

btscs lchange_med_yearly year conflict_id , g(lchangeyrs)
gen lchangeXchangeyrs=lchange_med*lchangeyrs
stcox med_onset i.lchange_med##c.lchangeyrs cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
dursel duration lchange_med lchangeXchangeyrs lchangeyrs cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A6 *

xtset conflict_id year
tab lchange_med_yearly
gen lchange_med_1=lchange_med_yearly
replace lchange_med_1=1 if l.lchange_med_yearly==1
gen lchange_med_2=lchange_med_1
replace lchange_med_2=1 if l.lchange_med_1==1
gen lchange_med_3=lchange_med_2
replace lchange_med_3=1 if l.lchange_med_2==1
gen lchange_med_4=lchange_med_3
replace lchange_med_4=1 if l.lchange_med_3==1
gen lchange_med_5=lchange_med_4
replace lchange_med_5=1 if l.lchange_med_4==1
gen lchange_med_6=lchange_med_5
replace lchange_med_6=1 if l.lchange_med_5==1
stset duration, id(stsetid) failure(ep_end==1)

stcox lchange_med_yearly med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox lchange_med_1 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox lchange_med_2 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox lchange_med_3 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox lchange_med_4 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
stcox lchange_med_5 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)

* Table A7 *

gen decay_final=2^(-1*(lchangeyrs/2))
stcox med_onset decay_final cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)

* Table A8 *

gen cwm_success_mod=cwm_success
replace cwm_success_mod=0 if conflict_id==234 & year>=1986 & year<=1990
replace cwm_success_mod=0 if conflict_id==315 & year>=1980 & year<=1984
replace cwm_success_mod=1 if conflict_id==419 & year>=2003 & year<=2004
btscs cwm_success_mod  year conflict_id , g(cwmsuccmodyrs)
gen medduration=medendyear-medstartyear+1
tab meddur
xtset conflict_id year
gen lastyear=0 if med_yearly==1 
replace lastyear = 1 if medduration!=medduration[_n+1] & med_yearly==1
tab cwm_success_mod lchange_med if lastyear==1

bysort medduration conflict_id medendyear medstartyear: egen lnpop_mean = mean(lnpop)  
bysort medduration conflict_id medendyear medstartyear: egen lngdppc_mean = mean(lngdppc)  
bysort medduration conflict_id medendyear medstartyear: egen rebels_groupnumber_mean = mean(rebels_groupnumber)  
bysort medduration conflict_id medendyear medstartyear: egen lnrebels_number_mean = mean(lnrebels_number)  
bysort medduration conflict_id medendyear medstartyear: egen polity2_a_mean = mean(polity2_a)  
bysort medduration conflict_id medendyear medstartyear: egen cumulative_intensity_max = max(cumulative_intensity)  
bysort medduration conflict_id medendyear medstartyear: egen rebels_polwing_mean = mean(rebels_polwing)  

heckprobit cwm_success_mod lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a c.cwmsuccmodyrs##c.cwmsuccmodyrs##c.cwmsuccmodyrs, select(med_onset= cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a c.medyrs##c.medyrs##c.medyrs) cluster(conflict_id)
heckprobit cwm_success_mod lchange_med lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a if lastyear!=0, select(med_onset= cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a c.medyrs##c.medyrs##c.medyrs) cluster(conflict_id)

* Table A9 * 

gen lnbeadbest=ln(bdeadbes)

stcox lchange_med med_onset lnbeadbest lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
dursel duration lchange_med lnbeadbest lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=lnbeadbest lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A10 *

gen polity_sq=polity2_a*polity2_a
stcox lchange_med med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a polity_sq, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a polity_sq , sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a polity_sq medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A11 *

gen Cold_War=0
replace Cold_War=1 if year<1990
stcox lchange_med med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a Cold_War, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a Cold_War, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a Cold_War medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A12 *

gen number_med=0
replace number_med=1 if mediator1!=""
replace number_med=2 if mediator2!=""
replace number_med=3 if mediator3!=""
replace number_med=4 if mediator4!=""
replace number_med=5 if mediator5!=""
replace number_med=6 if mediator6!=""
replace number_med=7 if mediator7!=""
replace number_med=8 if mediator8!=""
replace number_med=9 if mediator9!=""
replace number_med=10 if mediator10!=""
replace number_med=11 if mediator11!=""
tab number_med

gen number_med_min1=number_med-1 // For the interaction terms, subtract 1 from Number of Mediators to make constituent term interpretable 
gen number_medsquare_min1=number_med_min1*number_med_min1 // now means "effect of mediator leader change if one mediator"; previously meant "effect of mediator leader change if no mediator"
gen changemed_numbermed_min1=lchange_med*number_med_min1
gen changemed_numbermedsq_min1=lchange_med*number_medsquare_min1
gen number_medsquare=number_med*number_med

stcox lchange_med med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a number_med number_medsquare, nohr cluster(conflict_id)
stcox i.lchange_med##c.number_med_min1##c.number_med_min1 med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a number_med number_medsquare, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)
dursel duration lchange_med changemed_numbermed_min1 changemed_numbermedsq_min1 cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a number_med_min1 number_medsquare_min1, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A13 *

xtset conflict_id year
gen lchange_targov = leadertrans_sidea 
replace lchange_targov=lchange_targov[_n-1] if lchange_targov==0 & l.lchange_targov!=.

stset duration, id(stsetid) failure(ep_end==1)

stcox lchange_med med_onset cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a lchange_targov, nohr cluster(conflict_id)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a lchange_targov, sel(med_onset= cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a lchange_targov medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A14 *

tab incompatibility, gen (incompdummy)
dursel duration lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a incompdummy2 incompdummy3 medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A15 *

gen lchangeXpoli2 = lchange_med*avmed_polity2
gen lchangeXpwincsize = lchange_med*avmed_wincolsize
dursel duration lchange_med avmed_polity2 lchangeXpoli2 cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)
dursel duration lchange_med avmed_wincolsize lchangeXpwincsize cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A16 *

gen lchang_missings=lchange_med_yearly
replace lchang_missings=. if lchange_med_yearly==0
// net install rangestat.pkg //
rangestat (count) lchangenumber=lchang_missings, interval(year -62 -1) by(conflict_id)
replace lchangenumber = 0 if mi(lchangenumber)
sum lchangenumber

stcox med_onset lchangenumber cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, nohr cluster(conflict_id)
dursel duration lchangenumber cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a, sel(med_onset=cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a medyrs _spline1 _spline2 _spline3) dist(exp) cluster(conflict_id) rtcensor(exitsamp)

* Table A1 *

sum duration med_onset lchange_med cumulative_intensity lnpop lngdppc rebels_groupnumber rebels_polwing lnrebels_number polity2_a lchangeyrs cwm_success_mod lnbeadbest Cold_War number_med lchange_targov avmed_polity2 avmed_wincolsize lchangenumber

